Costs — skchange

Skip to main content
`Ctrl`+`K`

# Costs

`BaseCost`([param]) | Base class template for cost functions.
`L2Cost`([param]) | L2 cost of a constant mean.
`GaussianVarCost`([param]) | Univariate Gaussian likelihood cost.
`GaussianCovCost`([param]) | Multivariate Gaussian likelihood cost.

## Utility functions

`check_mean`(mean, X) | Check if the fixed mean parameter is valid.
`check_var`(var, X) | Check if the fixed variance parameter is valid.
`check_cov`(cov, X) | Check if the fixed covariance matrix parameter is valid.